changeset 2226:77c80807a14c

Merge
author asaha
date Wed, 07 Feb 2018 13:56:06 -0800
parents 8b0cb4829e01 (current diff) 6b0ed08eb078 (diff)
children 2e8ad76d7159
files .hgtags
diffstat 3 files changed, 13 insertions(+), 9 deletions(-) [+]
line wrap: on
line diff
--- a/.hgtags	Wed Feb 07 13:41:14 2018 -0800
+++ b/.hgtags	Wed Feb 07 13:56:06 2018 -0800
@@ -822,6 +822,8 @@
 173b2b978c05e59aa471e82be9013955ebd6b4de jdk8u162-b12
 a127ef57877d806f0840ccd6e7a2be337692fe6e jdk8u162-b31
 2c309abde14fbef07fe07304f493f770da0f5564 jdk8u162-b32
+f8f11c61855441c2d2ec1f87ba76e379fb371cd5 jdk8u162-b33
+a916a62cdb9cbdd7fd6ef5fa2e69092454f4fbab jdk8u162-b34
 d66f57333c7fcc735f87eb0903ffdc0aaf899b32 jdk8u171-b00
 6e7e84f6107b55b5cb98f5ac5e3bffa3e4b8892f jdk8u171-b01
 28f638905f78913e5b6dc89dd88e37223984a105 jdk8u171-b02
--- a/common/autoconf/toolchain.m4	Wed Feb 07 13:41:14 2018 -0800
+++ b/common/autoconf/toolchain.m4	Wed Feb 07 13:56:06 2018 -0800
@@ -1,5 +1,5 @@
 #
-# Copyright (c) 2011, 2015, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2011, 2018, Oracle and/or its affiliates. All rights reserved.
 # DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 #
 # This code is free software; you can redistribute it and/or modify it
@@ -1211,9 +1211,10 @@
         LDFLAGS_JDK="${LDFLAGS_JDK} -Xlinker --hash-style=both "
       fi
       if test "x$OPENJDK_TARGET_OS" = xlinux; then
-        # And since we now know that the linker is gnu, then add -z defs, to forbid
-        # undefined symbols in object files.
-        LDFLAGS_JDK="${LDFLAGS_JDK} -Xlinker -z -Xlinker defs"
+        # And since we now know that the linker is gnu, then add:
+        #   -z defs, to forbid undefined symbols in object files
+        #   -z noexecstack, to mark stack regions as non-executable
+        LDFLAGS_JDK="${LDFLAGS_JDK} -Xlinker -z -Xlinker defs -Xlinker -z -Xlinker noexecstack"
         if test "x$DEBUG_LEVEL" = "xrelease"; then
           # When building release libraries, tell the linker optimize them.
           # Should this be supplied to the OSS linker as well?
--- a/common/autoconf/generated-configure.sh	Wed Feb 07 13:41:14 2018 -0800
+++ b/common/autoconf/generated-configure.sh	Wed Feb 07 13:56:06 2018 -0800
@@ -3776,7 +3776,7 @@
 
 
 #
-# Copyright (c) 2011, 2015, Oracle and/or its affiliates. All rights reserved.
+# Copyright (c) 2011, 2018, Oracle and/or its affiliates. All rights reserved.
 # DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 #
 # This code is free software; you can redistribute it and/or modify it
@@ -3912,7 +3912,7 @@
 #CUSTOM_AUTOCONF_INCLUDE
 
 # Do not change or remove the following line, it is needed for consistency checks:
-DATE_WHEN_GENERATED=1501170108
+DATE_WHEN_GENERATED=1517507181
 
 ###############################################################################
 #
@@ -30178,9 +30178,10 @@
         LDFLAGS_JDK="${LDFLAGS_JDK} -Xlinker --hash-style=both "
       fi
       if test "x$OPENJDK_TARGET_OS" = xlinux; then
-        # And since we now know that the linker is gnu, then add -z defs, to forbid
-        # undefined symbols in object files.
-        LDFLAGS_JDK="${LDFLAGS_JDK} -Xlinker -z -Xlinker defs"
+        # And since we now know that the linker is gnu, then add:
+        #   -z defs, to forbid undefined symbols in object files
+        #   -z noexecstack, to mark stack regions as non-executable
+        LDFLAGS_JDK="${LDFLAGS_JDK} -Xlinker -z -Xlinker defs -Xlinker -z -Xlinker noexecstack"
         if test "x$DEBUG_LEVEL" = "xrelease"; then
           # When building release libraries, tell the linker optimize them.
           # Should this be supplied to the OSS linker as well?